1
0
forked from pool/virtualbox
virtualbox/vbox-default-os-type.diff

24 lines
1.1 KiB
Diff
Raw Normal View History

--- a/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp 2014-02-25 18:08:58.000000000 +0100
+++ b/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp 2014-03-03 15:18:07.298245235 +0100
@@ -203,15 +203,15 @@
if (iIndexWinXP != -1)
m_pTypeCombo->setCurrentIndex(iIndexWinXP);
}
/* Or select Ubuntu item for Linux family as default: */
else if (strFamilyId == "Linux")
{
- QString strDefaultID = "Ubuntu";
+ QString strDefaultID = "openSUSE";
if (ARCH_BITS == 64 && m_fSupportsHWVirtEx && m_fSupportsLongMode)
strDefaultID += "_64";
- int iIndexUbuntu = m_pTypeCombo->findData(strDefaultID, TypeID);
- if (iIndexUbuntu != -1)
- m_pTypeCombo->setCurrentIndex(iIndexUbuntu);
+ int iIndexopenSUSE = m_pTypeCombo->findData(strDefaultID, TypeID);
+ if (iIndexopenSUSE != -1)
+ m_pTypeCombo->setCurrentIndex(iIndexopenSUSE);
}
/* Else simply select the first one present: */
else m_pTypeCombo->setCurrentIndex(0);
@@ -203,15 +203,15 @@
m_pTypeCombo->setCurrentIndex(iIndexWinXP);
}
- /* Or select Ubuntu item for Linux family as default: */
+ /* Or select openSUSE item for Linux family as default: */
else if (strFamilyId == "Linux")
{